==> haskell-entropy-0.4.1.10-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 entropy
version:              0.4.1.10
visibility:           public
id:                   entropy-0.4.1.10-C5y4ZMubclPFkOssafbGqV
key:                  entropy-0.4.1.10-C5y4ZMubclPFkOssafbGqV
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             https://github.com/TomMD/entropy
synopsis:             A platform independent entropy source
description:
    A mostly platform independent method to obtain cryptographically strong entropy
    (RDRAND, urandom, CryptAPI, and patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.

category:             Data, Cryptography
abi:                  591ff201808811cb1f73cc3a09510194
exposed:              True
exposed-modules:      System.Entropy
hidden-modules:       System.EntropyNix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/entropy-0.4.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/entropy-0.4.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-entropy
hs-libraries:         HSentropy-0.4.1.10-C5y4ZMubclPFkOssafbGqV
depends:              base-4.16.4.0 bytestring-0.11.4.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html:         /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-entropy-0.4.1.11-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 entropy
version:              0.4.1.11
visibility:           public
id:                   entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
key:                  entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             https://github.com/TomMD/entropy
synopsis:             A platform independent entropy source
description:
    A mostly platform independent method to obtain cryptographically strong entropy
    (RDRAND, urandom, CryptAPI, and patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.

category:             Data, Cryptography
abi:                  6347fcbdccf671b3974d5c37bcd1dc9c
exposed:              True
exposed-modules:      System.Entropy
hidden-modules:       System.EntropyNix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/entropy-0.4.1.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/entropy-0.4.1.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/entropy-0.4.1.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-entropy
hs-libraries:         HSentropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
depends:              base-4.17.2.1 bytestring-0.11.5.3 unix-2.7.3
haddock-interfaces:   /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html:         /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
